@@ -67,6 +67,12 @@ struct spvm_compiler {
   // Current class base;
   int32_t cur_class_base;
   
+  // Starting file the starting module is loaded
+  const char* start_file;
+  
+  // Starting line the starting module is loaded
+  int32_t start_line;
+  
   // AST grammar
   SPVM_OP* op_grammar;
   
@@ -121,9 +127,6 @@ struct spvm_compiler {
   // Method ops
   SPVM_LIST* methods;
   
-  // Method absolute name symbol table
-  SPVM_HASH* method_symtable;
-
   // Field ops
   SPVM_LIST* fields;
   
@@ -131,7 +134,6 @@ struct spvm_compiler {
 };
 
 SPVM_COMPILER* SPVM_COMPILER_new();
-int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler);
 void SPVM_COMPILER_free(SPVM_COMPILER* compiler);
 void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler);
 SPVM_RUNTIME* SPVM_COMPILER_new_runtime(SPVM_COMPILER* compiler);
@@ -143,6 +145,9 @@ const char* SPVM_COMPILER_create_method_signature(SPVM_COMPILER* compiler, SPVM_
 const char* SPVM_COMPILER_create_field_signature(SPVM_COMPILER* compiler, SPVM_FIELD* field);
 const char* SPVM_COMPILER_create_class_var_signature(SPVM_COMPILER* compiler, SPVM_CLASS_VAR* class_var);
 
-int32_t SPVM_COMPILER_get_error_count(SPVM_COMPILER* compiler);
+int32_t SPVM_COMPILER_get_error_messages_length(SPVM_COMPILER* compiler);
+const char* SPVM_COMPILER_get_error_message(SPVM_COMPILER* compiler, int32_t index);
+
+int32_t SPVM_COMPILER_compile_spvm(SPVM_COMPILER* compiler, const char* class_name);
 
 #endif
