@@ -273,5 +273,44 @@ struct spvm_env {
   void* (*copy)(SPVM_ENV* env, void* object);
   void (*shorten)(SPVM_ENV* env, void* string, int32_t new_length);
   int32_t (*has_interface)(SPVM_ENV* env, void* object, int32_t interface_basic_type_id);
+  void* no_symbol_cache_flag;
+  void (*set_no_symbol_cache_flag)(SPVM_ENV* env, int32_t flag);
+  int32_t (*get_no_symbol_cache_flag)(SPVM_ENV* env);
+  void (*print)(SPVM_ENV* env, void* string);
+  void (*print_stderr)(SPVM_ENV* env, void* string);
+  SPVM_ENV* (*new_env_raw)(SPVM_ENV* env);
+  void (*free_env_raw)(SPVM_ENV* env);
+  int32_t (*init_env)(SPVM_ENV* env);
+  void (*call_init_blocks)(SPVM_ENV* env);
+  void (*cleanup_global_vars)(SPVM_ENV* env);
+  void* (*new_compiler)(SPVM_ENV* env);
+  void (*compiler_free)(SPVM_ENV* env, void* compiler);
+  void (*compiler_set_start_line)(SPVM_ENV* env, void* compiler, int32_t start_line);
+  int32_t (*compiler_get_start_line)(SPVM_ENV* env, void* compiler);
+  void (*compiler_set_start_file)(SPVM_ENV* env, void* compiler, const char* start_file);
+  const char* (*compiler_get_start_file)(SPVM_ENV* env, void* compiler);
+  void (*compiler_add_module_dir)(SPVM_ENV* env, void* compiler, const char* module_dir);
+  int32_t (*compiler_get_module_dirs_length )(SPVM_ENV* env, void* compiler);
+  const char* (*compiler_get_module_dir )(SPVM_ENV* env, void* compiler, int32_t module_dir_id);
+  int32_t (*compiler_compile_spvm)(SPVM_ENV* env, void* compiler, const char* class_name);
+  int32_t (*compiler_get_error_messages_length)(SPVM_ENV* env, void* compiler);
+  const char* (*compiler_get_error_message)(SPVM_ENV* env, void* compiler, int32_t index);
+  int32_t (*compiler_get_class_id)(SPVM_ENV* env, void* compiler, const char* class_name);
+  int32_t (*compiler_get_classes_length)(SPVM_ENV* env, void* compiler);
+  const char* (*compiler_get_class_name)(SPVM_ENV* env, void* compiler, int32_t class_id);
+  int32_t (*compiler_is_anon_class)(SPVM_ENV* env, void* compiler, int32_t class_id);
+  int32_t (*compiler_get_methods_length)(SPVM_ENV* env, void* compiler, int32_t class_id);
+  int32_t (*compiler_get_method_id)(SPVM_ENV* env, void* compiler, int32_t class_id, int32_t method_index_of_class);
+  int32_t (*compiler_get_method_id_by_name)(SPVM_ENV* env, void* compiler, const char* class_name, const char* method_name);
+  const char* (*compiler_get_method_name)(SPVM_ENV* env, void* compiler, int32_t method_id);
+  const char* (*compiler_get_method_signature)(SPVM_ENV* env, void* compiler, int32_t method_id);
+  int32_t (*compiler_is_anon_method)(SPVM_ENV* env, void* compiler, int32_t method_id);
+  int32_t (*compiler_is_init_block_method)(SPVM_ENV* env, void* compiler, int32_t method_id);
+  int32_t (*compiler_is_native_method)(SPVM_ENV* env, void* compiler, int32_t method_id);
+  int32_t (*compiler_is_precompile_method)(SPVM_ENV* env, void* compiler, int32_t method_id);
+  void* (*compiler_get_native_method_address)(SPVM_ENV* env, void* compiler, int32_t method_id);
+  void* (*compiler_get_precompile_method_address)(SPVM_ENV* env, void* compiler, int32_t method_id);
+  void (*compiler_set_native_method_address)(SPVM_ENV* env, void* compiler, int32_t method_id, void* address);
+  void (*compiler_set_precompile_method_address)(SPVM_ENV* env, void* compiler, int32_t method_id, void* address);
 };
 #endif
