@@ -158,9 +158,9 @@ enum {
   SPVM_OPCODE_C_ID_MULNUM_GET_FIELD_LONG,
   SPVM_OPCODE_C_ID_MULNUM_GET_FIELD_FLOAT,
   SPVM_OPCODE_C_ID_MULNUM_GET_FIELD_DOUBLE,
-  SPVM_OPCODE_C_ID_CALL_CLASS_METHOD,
-  SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD,
+  SPVM_OPCODE_C_ID_CALL_CLASS_METHOD_BY_ID,
+  SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD_BY_ID,
+  SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD_BY_SIGNATURE,
   SPVM_OPCODE_C_ID_ADD_INT,
   SPVM_OPCODE_C_ID_ADD_LONG,
   SPVM_OPCODE_C_ID_ADD_FLOAT,
@@ -348,7 +348,7 @@ enum {
   SPVM_OPCODE_C_ID_ARRAY_STORE_UNDEF,
   SPVM_OPCODE_C_ID_ARRAY_LENGTH,
   SPVM_OPCODE_C_ID_NEW_OBJECT,
-  SPVM_OPCODE_C_ID_NEW_STRING,
+  SPVM_OPCODE_C_ID_NEW_CONSTANT_STRING,
   SPVM_OPCODE_C_ID_NEW_OBJECT_ARRAY,
   SPVM_OPCODE_C_ID_NEW_MULTI_ARRAY,
   SPVM_OPCODE_C_ID_NEW_MULNUM_ARRAY,
@@ -458,6 +458,13 @@ enum {
   SPVM_OPCODE_C_ID_REFOP,
   SPVM_OPCODE_C_ID_DUMP,
   SPVM_OPCODE_C_ID_NEW_STRING_LEN,
+  SPVM_OPCODE_C_ID_IS_READ_ONLY,
+  SPVM_OPCODE_C_ID_MAKE_READ_ONLY,
+  SPVM_OPCODE_C_ID_MOVE_OBJECT_CHECK_READ_ONLY,
+  SPVM_OPCODE_C_ID_COPY,
+  SPVM_OPCODE_C_ID_HAS_INTERFACE,
+  SPVM_OPCODE_C_ID_CHECK_INTERFACE,
+  SPVM_OPCODE_C_ID_HAS_IMPLEMENT,
 };
 
 // Operation code is 64bit
