@@ -58,96 +58,101 @@ extern int SPVM_yydebug;
     CURRENT_CLASS = 268,
     MUTABLE = 269,
     DESCRIPTOR = 270,
-    IF = 271,
-    UNLESS = 272,
-    ELSIF = 273,
-    ELSE = 274,
-    FOR = 275,
-    WHILE = 276,
-    LAST = 277,
-    NEXT = 278,
-    SWITCH = 279,
-    CASE = 280,
-    DEFAULT = 281,
-    BREAK = 282,
-    EVAL = 283,
-    NAME = 284,
-    VAR_NAME = 285,
-    CONSTANT = 286,
-    EXCEPTION_VAR = 287,
-    UNDEF = 288,
-    VOID = 289,
-    BYTE = 290,
-    SHORT = 291,
-    INT = 292,
-    LONG = 293,
-    FLOAT = 294,
-    DOUBLE = 295,
-    STRING = 296,
-    OBJECT = 297,
-    TRUE = 298,
-    FALSE = 299,
-    END_OF_FILE = 300,
-    DOT3 = 301,
-    FATCAMMA = 302,
-    RW = 303,
-    RO = 304,
-    WO = 305,
-    INIT = 306,
-    NEW = 307,
-    RETURN = 308,
-    WEAKEN = 309,
-    DIE = 310,
-    WARN = 311,
-    PRINT = 312,
-    CURRENT_CLASS_NAME = 313,
-    UNWEAKEN = 314,
-    ASSIGN = 315,
-    SPECIAL_ASSIGN = 316,
-    LOGICAL_OR = 317,
-    LOGICAL_AND = 318,
-    BIT_OR = 319,
-    BIT_XOR = 320,
-    BIT_AND = 321,
-    NUMEQ = 322,
-    NUMNE = 323,
-    STREQ = 324,
-    STRNE = 325,
-    NUMGT = 326,
-    NUMGE = 327,
-    NUMLT = 328,
-    NUMLE = 329,
-    STRGT = 330,
-    STRGE = 331,
-    STRLT = 332,
-    STRLE = 333,
-    ISA = 334,
-    NUMERIC_CMP = 335,
-    STRING_CMP = 336,
-    SHIFT = 337,
-    DIVIDE = 338,
-    DIVIDE_UNSIGNED_INT = 339,
-    DIVIDE_UNSIGNED_LONG = 340,
-    REMAINDER = 341,
-    REMAINDER_UNSIGNED_INT = 342,
-    REMAINDER_UNSIGNED_LONG = 343,
-    LOGICAL_NOT = 344,
-    BIT_NOT = 345,
-    CREATE_REF = 346,
-    DEREF = 347,
-    PLUS = 348,
-    MINUS = 349,
-    CONVERT = 350,
-    SCALAR = 351,
-    STRING_LENGTH = 352,
-    ISWEAK = 353,
-    REFCNT = 354,
-    REFOP = 355,
-    DUMP = 356,
-    NEW_STRING_LEN = 357,
-    INC = 358,
-    DEC = 359,
-    ARROW = 360
+    MAKE_READ_ONLY = 271,
+    IMPLEMENT = 272,
+    IF = 273,
+    UNLESS = 274,
+    ELSIF = 275,
+    ELSE = 276,
+    FOR = 277,
+    WHILE = 278,
+    LAST = 279,
+    NEXT = 280,
+    SWITCH = 281,
+    CASE = 282,
+    DEFAULT = 283,
+    BREAK = 284,
+    EVAL = 285,
+    NAME = 286,
+    VAR_NAME = 287,
+    CONSTANT = 288,
+    EXCEPTION_VAR = 289,
+    UNDEF = 290,
+    VOID = 291,
+    BYTE = 292,
+    SHORT = 293,
+    INT = 294,
+    LONG = 295,
+    FLOAT = 296,
+    DOUBLE = 297,
+    STRING = 298,
+    OBJECT = 299,
+    TRUE = 300,
+    FALSE = 301,
+    END_OF_FILE = 302,
+    DOT3 = 303,
+    FATCAMMA = 304,
+    RW = 305,
+    RO = 306,
+    WO = 307,
+    INIT = 308,
+    NEW = 309,
+    RETURN = 310,
+    WEAKEN = 311,
+    DIE = 312,
+    WARN = 313,
+    PRINT = 314,
+    CURRENT_CLASS_NAME = 315,
+    UNWEAKEN = 316,
+    ASSIGN = 317,
+    SPECIAL_ASSIGN = 318,
+    LOGICAL_OR = 319,
+    LOGICAL_AND = 320,
+    BIT_OR = 321,
+    BIT_XOR = 322,
+    BIT_AND = 323,
+    NUMEQ = 324,
+    NUMNE = 325,
+    STREQ = 326,
+    STRNE = 327,
+    NUMGT = 328,
+    NUMGE = 329,
+    NUMLT = 330,
+    NUMLE = 331,
+    STRGT = 332,
+    STRGE = 333,
+    STRLT = 334,
+    STRLE = 335,
+    ISA = 336,
+    NUMERIC_CMP = 337,
+    STRING_CMP = 338,
+    SHIFT = 339,
+    DIVIDE = 340,
+    DIVIDE_UNSIGNED_INT = 341,
+    DIVIDE_UNSIGNED_LONG = 342,
+    REMAINDER = 343,
+    REMAINDER_UNSIGNED_INT = 344,
+    REMAINDER_UNSIGNED_LONG = 345,
+    LOGICAL_NOT = 346,
+    BIT_NOT = 347,
+    CREATE_REF = 348,
+    DEREF = 349,
+    PLUS = 350,
+    MINUS = 351,
+    CONVERT = 352,
+    SCALAR = 353,
+    STRING_LENGTH = 354,
+    ISWEAK = 355,
+    REFCNT = 356,
+    REFOP = 357,
+    DUMP = 358,
+    NEW_STRING_LEN = 359,
+    IS_READ_ONLY = 360,
+    COPY = 361,
+    HAS_IMPLEMENT = 362,
+    INC = 363,
+    DEC = 364,
+    ARROW = 365
   };
 #endif
 
